import { createRouter, createWebHistory } from "vue-router";
import DashboardView from "../views/DashboardView.vue";
import LoginView from "../views/LoginView.vue";

const router = createRouter({
  history: createWebHistory(import.meta.env.BASE_URL),
  routes: [
    {
      path: "/dashboard",
      name: "dashboard",
      component: DashboardView,
      children: [
        {
          path: "object-storage/buckets",
          name: "buckets",
          component: () => import("../views/object-storage/BucketsView.vue"),
          children: [
            {
              path: ":bucketName/:subFolders*",
              name: "bucket",
              component: () => import("../views/object-storage/BucketView.vue"),
              props: true,
            },
          ],
        },
        {
          path: "object-storage/s3-keys",
          name: "s3_keys",
          component: () => import("../views/object-storage/S3KeysView.vue"),
        },
        {
          path: "workflows",
          name: "workflows",
          component: () => import("../views/workflows/ListWorkflowsView.vue"),
        },
        {
          path: "developer/workflows",
          name: "workflows-developer",
          component: () => import("../views/workflows/MyWorkflowsView.vue"),
          meta: { requiresDeveloperRole: true },
        },
        {
          path: "workflows/:workflowId/",
          name: "workflow",
          component: () => import("../views/workflows/WorkflowView.vue"),
          props: true,
          children: [
            {
              path: "version/:versionId",
              name: "workflow-version",
              component: () =>
                import("../views/workflows/WorkflowVersionView.vue"),
              props: (route) => ({
                versionId: route.params.versionId,
                workflowId: route.params.workflowId,
                activeTab: route.query.tab ?? "description",
              }),
            },
          ],
        },
      ],
    },
    {
      path: "/login",
      name: "login",
      component: LoginView,
    },
    {
      path: "/",
      redirect: { name: "buckets" },
    },
    {
      path: "/:pathMatch(.*)",
      component: () => import("../views/NotFoundView.vue"),
    },
  ],
});

export default router;
